//*****************************************************************************
//
// Copyright (C) 2014 Texas Instruments Incorporated - http://www.ti.com/ 
// 
// 
//  Redistribution and use in source and binary forms, with or without 
//  modification, are permitted provided that the following conditions 
//  are met:
//
//    Redistributions of source code must retain the above copyright 
//    notice, this list of conditions and the following disclaimer.
//
//    Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the 
//    documentation and/or other materials provided with the   
//    distribution.
//
//    Neither the name of Texas Instruments Incorporated nor the names of
//    its contributors may be used to endorse or promote products derived
//    from this software without specific prior written permission.
//
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
//  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
//  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
//  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
//  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
//  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
//  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
//  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
//  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
//  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
//*****************************************************************************

//*****************************************************************************
//
// Application Name     - SPI Demo
// Application Overview - The demo application focuses on showing the required 
//                        initialization sequence to enable the CC3200 SPI 
//                        module in full duplex 4-wire master and slave mode(s).
// Application Details  -
// http://processors.wiki.ti.com/index.php/CC32xx_SPI_Demo
// or
// docs\examples\CC32xx_SPI_Demo.pdf
//
//*****************************************************************************


//*****************************************************************************
//
//! \addtogroup SPI_Demo
//! @{
//
//*****************************************************************************

// Standard includes
#include <string.h>

// Driverlib includes
#include "hw_types.h"
#include "hw_memmap.h"
#include "hw_common_reg.h"
#include "hw_ints.h"
#include "spi.h"
#include "rom.h"
#include "rom_map.h"
#include "utils.h"
#include "prcm.h"
#include "uart.h"
#include "interrupt.h"
#include "gpio.h"
#include "hw_mcspi.h"
#include "hw_wdt.h"
#include "TI_ADS1293.h"
#include "TI_ADS1293_register_settings_1.h"
// Common interface includes
#include "uart_if.h"
#include "pinmux.h"


typedef unsigned char           uint8_t;
typedef unsigned short int      uint16_t;
typedef unsigned int            uint32_t;
uint8_t ADS1293_ADCDataReady = 0;
unsigned long data;
unsigned long status;
unsigned long dataa;
uint8_t pin;
void TI_ADS1293_SPIWriteReg(uint8_t addr, uint8_t value);
void TI_ADS1293_SPIStreamReadReg(unsigned long *buffer,uint8_t count);
void TI_ADS1293_WriteRegSettings(void);
#define APPLICATION_VERSION     "1.1.1"
//*****************************************************************************
//
// Application Master/Slave mode selector macro
//
// MASTER_MODE = 1 : Application in master mode
// MASTER_MODE = 0 : Application in slave mode
//
//*****************************************************************************
#define MASTER_MODE      1

#define SPI_IF_BIT_RATE  100000
#define TR_BUFF_SIZE     100

#define MASTER_MSG       "This is CC3200 SPI Master Application\n\r"
#define SLAVE_MSG        "This is CC3200 SPI Slave Application\n\r"

//*****************************************************************************
//                 GLOBAL VARIABLES -- Start
//*****************************************************************************
static unsigned char g_ucTxBuff[TR_BUFF_SIZE];
static unsigned char g_ucRxBuff[TR_BUFF_SIZE];
unsigned long re[1000];
static unsigned char ucTxBuffNdx;
static unsigned char ucRxBuffNdx;
int address_flag=1;
unsigned char  RegAddress[60]={0x00,0x01,0x02,0x03,0x04,0x05,0x06,0x07,0x08,0x09,0x0A,0x0B,0x0C,0x0D,0x0E,0x0F,0x10,0x11,0x12,0x13,0x14,0x15,0x16,0x17,
		0x18,0x19,0x1A,0x1B,0x1C,0x1D,0x21,0x22,0x23,0x24,0x25,0x26,0x27,0x28,0x29,0x2A,0x2E,0x2F,
		0x30,0x31,0x32,0x33,0x34,0x35,0x36,0x37,0x38,0x39,0x3A,0x3B,0x3C,0x3D,0x3E,0x3F,0x40,0x50};
unsigned char  RegValue[60]={0x01,0x11,0x19,0x2E,0x00,0x00,0x08,0x00,0x00,0x00,0x07,0x00,0x04,0x01,0x02,0x03,0x01,0x00,0x04,0x00,0x00,0x00,0x00,0x05,
		0x00,0x72,0x12,0x12,0x36,0x00,0x02,0x02,0x02,0x02,0x00,0x00,0x08,0x00,0x00,0x00,0x33,0x70,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x50};
long number=0;
int writeReg_index=0;
int data_ready=0;
#define SAMPLE_ARRAY_SIZE 10                                                   // Store last 10 ecg samples for processing
#define CH_DATA_SIZE 6                                                         // 6 bytes: ch1 ecg + ch2 ecg
uint32_t adc_sample_array[SAMPLE_ARRAY_SIZE];
#if defined(ccs)
extern void (* const g_pfnVectors[])(void);
#endif
#if defined(ewarm)
extern uVectorEntry __vector_table;
#endif
//*****************************************************************************
//                 GLOBAL VARIABLES -- End
//*****************************************************************************
void TI_ADS1293_SPIWriteReg(uint8_t addr, uint8_t value)
{

	unsigned long receiveData;
	uint8_t inst;
	MAP_SPICSEnable(GSPI_BASE);
		inst=addr & ADS1293_WRITE_BIT;
		SPIDataPut(GSPI_BASE,inst);
		SPIDataGet(GSPI_BASE,&receiveData);
		inst=value;
		SPIDataPut(GSPI_BASE,inst);
		SPIDataGet(GSPI_BASE,&receiveData);
	while(!(HWREG(GSPI_BASE + MCSPI_O_CH0STAT)&MCSPI_CH0STAT_TXS))
	{
	}

	MAP_SPICSDisable(GSPI_BASE);
}
void TI_ADS1293_SPIStreamReadReg(unsigned long *buffer,uint8_t count)
{
	uint8_t inst;
	unsigned long i;
	MAP_SPICSEnable(GSPI_BASE);
	inst = ADS1293_READ_BIT | TI_ADS1293_DATA_LOOP_REG;     // read from data loop register
    MAP_SPIDataPut(GSPI_BASE,inst);
    for(i=0;i<count;i++)
    {
    	MAP_SPIDataPut(GSPI_BASE,0x00);                    // dummy write so we can read data
    	while(!(HWREG(GSPI_BASE + MCSPI_O_CH0STAT)&MCSPI_CH0STAT_TXS))
    		{
    		}
    	MAP_SPIDataGet(GSPI_BASE,buffer+i);
    }
    MAP_SPICSDisable(GSPI_BASE);
}
static void GPIO4_Handler()
{
    GPIOIntClear(GPIOA0_BASE,GPIO_INT_PIN_4);                          //clear IFG
    ADS1293_ADCDataReady = 1;
}

//*****************************************************************************
//
//! SPI Slave Interrupt handler
//!
//! This function is invoked when SPI slave has its receive register full or
//! transmit register empty.
//!
//! \return None.
//
//*****************************************************************************
void SlaveIntHandler()
{
    unsigned long ulRecvData;
    unsigned long ulStatus;

    ulStatus = MAP_SPIIntStatus(GSPI_BASE,true);

    MAP_SPIIntClear(GSPI_BASE,SPI_INT_RX_FULL|SPI_INT_TX_EMPTY);

    if(ulStatus & SPI_INT_TX_EMPTY)
    {
        MAP_SPIDataPut(GSPI_BASE,g_ucTxBuff[ucTxBuffNdx%TR_BUFF_SIZE]);
        ucTxBuffNdx++;
    }

    if(ulStatus & SPI_INT_RX_FULL)
    {
        MAP_SPIDataGetNonBlocking(GSPI_BASE,&ulRecvData);
        g_ucTxBuff[ucRxBuffNdx%TR_BUFF_SIZE] = ulRecvData;
        Report("%c",ulRecvData);
        ucRxBuffNdx++;
    }
}

//*****************************************************************************
//
//! SPI Master mode main loop
//!
//! This function configures SPI modelue as master and enables the channel for
//! communication
//!
//! \return None.
//
//*****************************************************************************
void MasterMain()
{

    unsigned long ulUserData;
    unsigned long ulDummy;
    writeReg_index=0;
    address_flag=1;
    //
    // Initialize the message
    //
    memcpy(g_ucTxBuff,MASTER_MSG,sizeof(MASTER_MSG));

    //
    // Set Tx buffer index
    //
    ucTxBuffNdx = 0;
    ucRxBuffNdx = 0;

    //
    // Reset SPI
    //
    MAP_SPIReset(GSPI_BASE);

    //
    // Configure SPI interface
    //
    MAP_SPIConfigSetExpClk(GSPI_BASE,MAP_PRCMPeripheralClockGet(PRCM_GSPI),
                     SPI_IF_BIT_RATE,SPI_MODE_MASTER,SPI_SUB_MODE_0,
                     (SPI_SW_CTRL_CS |
                     SPI_4PIN_MODE |
                     SPI_TURBO_OFF |
                     SPI_CS_ACTIVEHIGH |
                     SPI_WL_8));

    //
    // Register Interrupt Handler
        //
   // MAP_SPIIntRegister(GSPI_BASE,MasterIntHandler);

        //
        // Enable Interrupts
        //
   // MAP_SPIIntEnable(GSPI_BASE,SPI_INT_RX_FULL|SPI_INT_TX_EMPTY);
    //MAP_SPIIntEnable(GSPI_BASE,SPI_INT_TX_EMPTY);
    // Enable SPI for communication
    //
    MAP_SPIEnable(GSPI_BASE);

    //
    // Print mode on uart
    //
  //  Message("Enabled SPI Interface in Master Mode\n\r");

    //
    // User input
    //
   // Report("Press any key to transmit data....");

    //
    // Read a character from UART terminal
    //
 //   ulUserData = MAP_UARTCharGet(UARTA0_BASE);


    //
    // Send the string to slave. Chip Select(CS) needs to be
    // asserted at start of transfer and deasserted at the end.
    //
  //  MAP_SPITransfer(GSPI_BASE,g_ucTxBuff,g_ucRxBuff,50,
   //         SPI_CS_ENABLE|SPI_CS_DISABLE);

    //
    // Report to the user
    //
    Report("\n\rSend      %s",g_ucTxBuff);
    Report("Received  %s",g_ucRxBuff);

    //
    // Print a message
    //
    Report("\n\rType here (Press enter to exit) :");
    //
    // Initialize variable
    //
    ulUserData = 0;

    //
    // Enable Chip select
    //


    //
    // Loop until user "Enter Key" is
    // pressed
    //
    unsigned long t=0;
    number=0;
    uint8_t inst=0;
 /*  while(number!=60)
    {
    	MAP_SPICSEnable(GSPI_BASE);
    	inst=RegAddress[number] & ADS1293_WRITE_BIT;
    	MAP_SPIDataPut(GSPI_BASE,inst);
    	MAP_SPIDataGet(GSPI_BASE,&t);
    	inst=RegValue[number];
    	MAP_SPIDataPut(GSPI_BASE,inst);
    	MAP_SPIDataGet(GSPI_BASE,&t);
    	while(!(HWREG(GSPI_BASE + MCSPI_O_CH0STAT)&MCSPI_CH0STAT_TXS))
    	  {
    	  }
    	MAP_SPICSDisable(GSPI_BASE);
    	number++;
    }*/
    GPIODirModeSet(GPIOA0_BASE,GPIO_PIN_3,GPIO_DIR_MODE_IN);       //pin_3 use as DRDYB channel
  //  GPIOIntTypeSet(GPIOA0_BASE,GPIO_PIN_4,GPIO_RISING_EDGE);
  //  GPIOIntClear(GPIOA0_BASE,GPIO_PIN_4);
                                                                    //clear interrupt flag
   // GPIOIntEnable(GPIOA0_BASE,GPIO_PIN_4);
                                                                    //enable interrupt
  //  GPIOIntRegister(GPIOA0_BASE,GPIO4_Handler);
  /*  while(number!=60)
    {
    	TI_ADS1293_SPIWriteReg(RegAddress[number],RegValue[number]);
    	number++;
    }*/
while(1){
    MAP_SPICSEnable(GSPI_BASE);
    MAP_SPIDataPut(GSPI_BASE, ADS1293_WRITE_BIT & TI_ADS1293_ALARM_FILTER_REG);
  //  data=HWREG(GSPI_BASE + MCSPI_O_RX0);
  //  status=HWREG(GSPI_BASE+MCSPI_O_CH0STAT);
   SPIDataGet(GSPI_BASE,&data);
   MAP_SPIDataPut(GSPI_BASE,0xEE);
 //  data=HWREG(GSPI_BASE + MCSPI_O_RX0);
    //   status=HWREG(GSPI_BASE+MCSPI_O_CH0STAT);
   SPIDataGet(GSPI_BASE,&data);
   MAP_SPIDataPut(GSPI_BASE,0x00);
   SPIDataGet(GSPI_BASE,&data);
    MAP_SPIDataPut(GSPI_BASE, ADS1293_READ_BIT | TI_ADS1293_ALARM_FILTER_REG);
   SPIDataGet(GSPI_BASE,&dataa);
   MAP_SPIDataPut(GSPI_BASE,0x00);
   SPIDataGet(GSPI_BASE,&dataa);
   number=0;
}
      //  TI_ADS1293_SPIWriteReg(RegAddress[0],0x2E);

  //  SPITransfer8(GSPI_BASE,RegAddress[0] | ADS1293_READ_BIT,&data,1,SPI_CS_ENABLE|SPI_CS_DISABLE);
  //  SPITransfer8(GSPI_BASE,0x00,&data,1,SPI_CS_ENABLE|SPI_CS_DISABLE);
   /* while(1){
    MAP_SPIDataPut(GSPI_BASE,ADS1293_WRITE_BIT & RegAddress[1]);
    MAP_SPIDataGet(GSPI_BASE,&data);
    MAP_SPIDataPut(GSPI_BASE,0xAA);
    MAP_SPIDataGet(GSPI_BASE,&data);
    MAP_SPIDataPut(GSPI_BASE,ADS1293_READ_BIT | RegAddress[1]);
    MAP_SPIDataGet(GSPI_BASE,&data);
    MAP_SPIDataPut(GSPI_BASE,0x00);
    SPIDataGet(GSPI_BASE,&dataa);
    }*/


    /*
    MAP_SPIDataPut(GSPI_BASE,ADS1293_READ_BIT | RegAddress[1] );
    SPIDataGet(GSPI_BASE,&data);
    MAP_SPIDataPut(GSPI_BASE,0x00);
    SPIDataGet(GSPI_BASE,&data);
     MAP_SPIDataPut(GSPI_BASE,RegAddress[1]);
          SPIDataGet(GSPI_BASE,&data);
          MAP_SPIDataPut(GSPI_BASE,0x6E);
         SPIDataGet(GSPI_BASE,&data);
         number=0;

         MAP_SPIDataPut(GSPI_BASE,0x33);
         SPIDataGet(GSPI_BASE,&data);
*/
    //    SPITransfer8(GSPI_BASE,RegAddress[0] | ADS1293_READ_BIT,&data,1,SPI_CS_ENABLE|SPI_CS_DISABLE);
    //    SPITransfer8(GSPI_BASE,0x00,&data,1,SPI_CS_ENABLE|SPI_CS_DISABLE);
     //   SPITransfer(GSPI_BASE,RegAddress[1] | ADS1293_READ_BIT,&data,1,SPI_CS_ENABLE);
     //   SPITransfer(GSPI_BASE,0x00,&data,1,SPI_CS_DISABLE);

    //    MAP_SPIDataPut(GSPI_BASE,0x00);
    //    SPIDataGet(GSPI_BASE,&data);

      TI_ADS1293_SPIWriteReg(TI_ADS1293_FLEX_CH1_CN_REG,
                              TI_ADS1293_FLEX_CH1_CN_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_FLEX_CH2_CN_REG,
                              TI_ADS1293_FLEX_CH2_CN_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_FLEX_CH3_CN_REG,
                              TI_ADS1293_FLEX_CH3_CN_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_FLEX_PACE_CN_REG,
                              TI_ADS1293_FLEX_PACE_CN_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_FLEX_VBAT_CN_REG,
                              TI_ADS1293_FLEX_VBAT_CN_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_LOD_CN_REG,
                              TI_ADS1293_LOD_CN_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_LOD_EN_REG,
                              TI_ADS1293_LOD_EN_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_LOD_CURRENT_REG,
                              TI_ADS1293_LOD_CURRENT_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_LOD_AC_CN_REG,
                              TI_ADS1293_LOD_AC_CN_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_CMDET_EN_REG,
                              TI_ADS1293_CMDET_EN_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_CMDET_CN_REG,
                              TI_ADS1293_CMDET_CN_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_RLD_CN_REG,
                              TI_ADS1293_RLD_CN_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_WILSON_EN1_REG,
                              TI_ADS1293_WILSON_EN1_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_WILSON_EN2_REG,
                              TI_ADS1293_WILSON_EN2_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_WILSON_EN3_REG,
                              TI_ADS1293_WILSON_EN3_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_WILSON_CN_REG,
                              TI_ADS1293_WILSON_CN_REG_VALUE);

      TI_ADS1293_SPIWriteReg(TI_ADS1293_REF_CN_REG,
                              TI_ADS1293_REF_CN_REG_VALUE);

      TI_ADS1293_SPIWriteReg(TI_ADS1293_OSC_CN_REG,
                              TI_ADS1293_OSC_CN_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_AFE_RES_REG,
                              TI_ADS1293_AFE_RES_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_AFE_SHDN_CN_REG,
                              TI_ADS1293_AFE_SHDN_CN_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_AFE_FAULT_CN_REG,
                              TI_ADS1293_AFE_FAULT_CN_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_AFE_DITHER_EN_REG,
                              TI_ADS1293_AFE_DITHER_EN_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_AFE_PACE_CN_REG,
                              TI_ADS1293_AFE_PACE_CN_REG_VALUE);

      TI_ADS1293_SPIWriteReg(TI_ADS1293_R2_RATE_REG,
                              TI_ADS1293_R2_RATE_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_R3_RATE1_REG,
                              TI_ADS1293_R3_RATE1_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_R3_RATE2_REG,
                              TI_ADS1293_R3_RATE2_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_R3_RATE3_REG,
                              TI_ADS1293_R3_RATE3_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_P_DRATE_REG,
                              TI_ADS1293_P_DRATE_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_DIS_EFILTER_REG,
                              TI_ADS1293_DIS_EFILTER_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_DRDYB_SRC_REG,
                              TI_ADS1293_DRDYB_SRC_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_SYNCOUTB_SRC_REG,
                              TI_ADS1293_SYNCOUTB_SRC_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_MASK_DRDYB_REG,
                              TI_ADS1293_MASK_DRDYB_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_MASK_ERR_REG,
                              TI_ADS1293_MASK_ERR_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_ALARM_FILTER_REG,
                              TI_ADS1293_ALARM_FILTER_REG_VALUE);
      TI_ADS1293_SPIWriteReg(TI_ADS1293_CH_CNFG_REG,
                              TI_ADS1293_CH_CNFG_REG_VALUE);



   TI_ADS1293_SPIWriteReg(TI_ADS1293_CONFIG_REG, TI_ADS1293_CONFIG_REG_VALUE | ADS1293_START_CONV);
   MAP_SPICSEnable(GSPI_BASE);

   int i=0;
   while(true)
   {
	 /* MAP_SPIDataPut(GSPI_BASE,TI_ADS1293_DATA_CH1_ECG_H_REG & ADS1293_READ_BIT);
	  SPIDataGet(GSPI_BASE,&data);
	  re[i]=data & 0xFF;
	        i++;
	  MAP_SPIDataPut(GSPI_BASE,TI_ADS1293_DATA_CH1_ECG_M_REG & ADS1293_READ_BIT);
	  SPIDataGet(GSPI_BASE,&data);
	  re[i]=data & 0xFF;
	        i++;
	  MAP_SPIDataPut(GSPI_BASE,TI_ADS1293_DATA_CH1_ECG_L_REG & ADS1293_READ_BIT);
	  SPIDataGet(GSPI_BASE,&data);
      re[i]=data & 0xFF;
      i++;*/
	   if(GPIOPinRead(0,3)>0){
		   pin=GPIOPinRead(0,3);
		/*   ADS1293_ADCDataReady=0;
		   MAP_SPIDataPut(GSPI_BASE,TI_ADS1293_DATA_LOOP_REG & ADS1293_READ_BIT);
	       SPIDataGet(GSPI_BASE,&data);
	   	  re[i]=data & 0xFF;
	   	        i++;*/
		   //i=i;
		      MAP_SPIDataPut(GSPI_BASE,TI_ADS1293_DATA_CH1_ECG_H_REG | ADS1293_READ_BIT);
		   	  SPIDataGet(GSPI_BASE,&data);
		   	MAP_SPIDataPut(GSPI_BASE,0x00);
		   	SPIDataGet(GSPI_BASE,&data);
		   	  //re[i]=data & 0xFF;
		   	   //     i++;
		   	  re[i] = data;
		   	  MAP_SPIDataPut(GSPI_BASE,TI_ADS1293_DATA_CH1_ECG_M_REG | ADS1293_READ_BIT);
		   	  SPIDataGet(GSPI_BASE,&data);
		   	MAP_SPIDataPut(GSPI_BASE,0x11);
		   	SPIDataGet(GSPI_BASE,&data);
		   	  //re[i]=data & 0xFF;
		   	      //  i++;
		   	  re[i] = re[i] << 8 + 	data;
		   	  MAP_SPIDataPut(GSPI_BASE,TI_ADS1293_DATA_CH1_ECG_L_REG | ADS1293_READ_BIT);
		   	  SPIDataGet(GSPI_BASE,&data);
		  //       re[i]=data & 0xFF;
		   	  re[i] = re[i] << 8 + data;
		         i++;






        if(i==999)
    	  break;
	   }

   }


}

//*****************************************************************************
//
//! SPI Slave mode main loop
//!
//! This function configures SPI modelue as slave and enables the channel for
//! communication
//!
//! \return None.
//
//*****************************************************************************
//*****************************************************************************
static void
BoardInit(void)
{
/* In case of TI-RTOS vector table is initialize by OS itself */
#ifndef USE_TIRTOS
  //
  // Set vector table base
  //
#if defined(ccs)
    MAP_IntVTableBaseSet((unsigned long)&g_pfnVectors[0]);
#endif
#if defined(ewarm)
    MAP_IntVTableBaseSet((unsigned long)&__vector_table);
#endif
#endif
    //
    // Enable Processor
    //
    MAP_IntMasterEnable();
    MAP_IntEnable(FAULT_SYSTICK);

    PRCMCC3200MCUInit();
}

//*****************************************************************************
//
//! Main function for spi demo application
//!
//! \param none
//!
//! \return None.
//
//*****************************************************************************
void main()

{
    //
    // Initialize Board configurations
    //
    BoardInit();
   // HWREG(WDT_BASE+WDT_O_LOCK) |=WDT_LOCK_M;
    //
    // Muxing UART and SPI lines.
    //
    PinMuxConfig();

    //
    // Enable the SPI module clock
    //
    MAP_PRCMPeripheralClkEnable(PRCM_GSPI,PRCM_RUN_MODE_CLK);

    //
    // Initialising the Terminal.
    //
    InitTerm();

    //
    // Clearing the Terminal.
    //
    ClearTerm();

    //
    // Display the Banner
    //
    Message("\n\n\n\r");
    Message("\t\t   ********************************************\n\r");
    Message("\t\t        CC3200 SPI Demo Application  \n\r");
    Message("\t\t   ********************************************\n\r");
    Message("\n\n\n\r");

    //
    // Reset the peripheral
    //
    MAP_PRCMPeripheralReset(PRCM_GSPI);

//#if MASTER_MODE

    MasterMain();

//#else

//    SlaveMain();

//#endif
    unsigned long  read_buf[CH_DATA_SIZE];
    uint32_t adc_data;
    uint8_t count,i=0;
    while(1)
    {
     if(ADS1293_ADCDataReady==1)
     {
    	 ADS1293_ADCDataReady=0;
    	 count = CH_DATA_SIZE;
    	 TI_ADS1293_SPIStreamReadReg(read_buf, count);                            // read adc output into read_buf

    	 adc_data = ((uint32_t) read_buf[0] << 16)
    	                  | ((uint16_t) read_buf[1] << 8) | read_buf[2];                // form raw adc output data
    	       adc_sample_array[i] = adc_data;
    	             if (++i == SAMPLE_ARRAY_SIZE)                                            // sample array is full
    	             {
    	               i = 0;
    	             }
     }
    }

}

